% COUNTERF.M creates a counterfactual analysis by eliminating the monetary policy
% shock from some given date onwards and recalculating the historical series.
% An impulse vector aa needs to be given.

COUNTER_PLOT = 0;
DO_EPS = 1;
LEADDATES = 10;
LAGDATES = 48;

STARTDATE = 177; % Corresponds to 1.9797e+003, i.e. Aug. 1979, start of
                 % tenure of Paul Volcker as Fed chairman.
monindic; % Calculates the monetary indicator.
xxnew = xx;
sernew = series;
tt = max(size(series));
for date = STARTDATE : tt-1,
   y_new = xxnew(date-nlags,:)*bb + epsln(date-nlags,:)  - mon_ind(date-nlags)*aa';
   sernew(date,:) = y_new;
   xxnew(date-nlags+1,:)=[xx(date-nlags+1,1:LEADTRENDS), y_new,...
                             xxnew(date-nlags,LEADTRENDS+1:LEADTRENDS+nvar*(nlags-1))];
end;

if COUNTER_PLOT,
   for j = 1 : nvar,
      piece = STARTDATE-LEADDATES : STARTDATE + LAGDATES;
      if j < 6,
         rscl = 100/series(177,j);
      else
         rscl = scale_fct(j);
      end;
      plot(time(piece),series(piece,j)*rscl,time(piece),sernew(piece,j)*rscl,'-.');
      title(['Counterfactual analysis for ',names(j,:)]);
      xlabel('Date');
      if j < 6,
         ylabel('Value of series (Aug. 1979 = 100)');
      else
         ylabel('Percent');
      end;
      text(time(piece(20)),series(piece(20),j)*rscl,'Actual');
      text(time(piece(30)),sernew(piece(30),j)*rscl,'Counterfactual');
      if (DO_EPS),
         if j == 1,
            print -deps counter1.eps
         elseif j == 2,
            print -deps counter2.eps
         elseif j == 3,
            print -deps counter3.eps
         elseif j == 4,
            print -deps counter4.eps
         elseif j == 5,
            print -deps counter5.eps
         elseif j == 6,
            print -deps counter6.eps
         else
         end;
      end;
      pause;
   end;
end;
