% MONTPLOT.M plots the results of a Monte-Carlo-Analysis.  
DO_PLOTS = 1;
DO_EPSFILES = 1;
PLOT_HOR = 60;
DO_IR_FOR_MEAN = 0;
DO_FV_FOR_MEAN = 0;
DO_SERNEW_FOR_MEAN = 0;
DO_IR_SORT = 1;
DO_FV_SORT = 1;
DO_SERNEW_SORT = 1;
DO_2STDDEV = 0; % = 1: two standard dev. error bands, = 0: one standard dev. error bands

FONT_SIZE = 16; % FontSize

CHOICE = 'z';

if DO_2STDDEV, % converting two standard dev. into quantiles, using normal distrib:
   uq = 0.9772;
   lq = 0.0228;
else
   uq = 0.8413;
   lq = 0.1587;
end;

global ir LEADTRENDS aa nlags nvar varvec bb scale_fct
global eigsqrt eigvec vv ir aa nvar sphere
global HOW_FAR WEIGHTS SIDE SCALE ALPHSUM

if CHOICE == '0',
   load montchol
   DO_COUNTER = 0;
elseif CHOICE == 'a', 
   load monte_a
   DO_COUNTER = 0;
elseif CHOICE == 'b', 
   load monte_b
   DO_COUNTER = 0;
elseif CHOICE == '2',
   load monte_b2
   DO_COUNTER = 1;
elseif CHOICE == 'c', 
   load monte_c
   DO_COUNTER = 0;
else
   load monte
   DO_COUNTER = 1;
end;



PLOT_IMP = min(PLOT_HOR,HORIZON+1);
PLOT_VAR = min(PLOT_HOR,HORI_VAR);
hor_i = (0 : PLOT_IMP-1)/12;
hor_v = (0 : PLOT_VAR-1)/12;

if DO_PLOTS,
   for j = 1 : min(nvar,NVAR_MAX),
      if j == 1,
         ir = ir1;
         ir_m = mean(ir1');
         ir_s = std(ir1');
      elseif j == 2,
         ir = ir2;
         ir_m = mean(ir2');
         ir_s = std(ir2');
      elseif j == 3,
         ir = ir3;
         ir_m = mean(ir3');
         ir_s = std(ir3');
      elseif j == 4,
         ir = ir4;
         ir_m = mean(ir4');
         ir_s = std(ir4');
      elseif j == 5,
         ir = ir5;
         mean(ir5');
         ir_s = std(ir5');
      elseif j == 6,
         ir = ir6;
         ir_m = mean(ir6');
         ir_s = std(ir6');
      else
      end;
      ir_m = ir_m(1:PLOT_IMP);
      ir_s = ir_s(1:PLOT_IMP);
      if DO_IR_SORT,
         % disp('Impulse responses: Calculating Error Bands');
         % disp(' directly from the drawn distribution');
         ir = ir(1:PLOT_IMP,:);
         ir_sort = sort(ir');
         ir_sort = ir_sort';
         number_of_draws = size(ir_sort);
         number_of_draws = number_of_draws(2);
         ir_mid  = interp1(1:number_of_draws,ir_sort',.5*(number_of_draws-1)+1);
         ir_up   = interp1(1:number_of_draws,ir_sort',uq*(number_of_draws-1)+1);
         ir_down = interp1(1:number_of_draws,ir_sort',lq*(number_of_draws-1)+1);
      else
         % disp('Impulse responses: Calculating Error Bands');
         % disp(' via means and standard deviations');
         ir_mid   = ir_m;
         if DO_2STDDEV,
            ir_up    = ir_m + 2 * ir_s;
            ir_down  = ir_m - 2 * ir_s;
         else
            ir_up    = ir_m +  ir_s;
            ir_down  = ir_m -  ir_s;
         end;
      end;
      if DO_IR_FOR_MEAN,
         hndl = plot(hor_i,ir_mid,'-',hor_i,ir_up,'-',hor_i,ir_down,'-',...
              hor_i,ir_par(1:PLOT_IMP,j),'-.',hor_i,0*hor_i);
         if DO_IR_SORT,
            % text(hor_i(5),ir_mid(5),'median i.r.');
         else
            % text(hor_i(5),ir_mid(5),'mean i.r.');
         end;
         % text(hor_i(20),ir_par(20,j),'i.r. for mean');
      else
         hndl = plot(hor_i,ir_mid,'-',hor_i,ir_up,'-',hor_i,ir_down,'-',hor_i,0*hor_i);
      end;
      title(['Impulse response for ',names(j,:)]);
      xlabel('years'); % xlabel('month');
      ylabel('Percent'); % ylabel('response');
      
      hpar = get(hndl(1),'Parent');
      set(hpar,'FontSize',FONT_SIZE);
      ht = get(hpar,'Title');
      set(ht,'FontSize',FONT_SIZE);
      hx = get(hpar,'XLabel');
      set(hx,'FontSize',FONT_SIZE);
      hy = get(hpar,'YLabel');
      set(hy,'FontSize',FONT_SIZE);
      if DO_EPSFILES,
         if j == 1,
            print -deps imp1.eps
         elseif j == 2,
            print -deps imp2.eps
         elseif j == 3,
            print -deps imp3.eps
         elseif j == 4,
            print -deps imp4.eps
         elseif j == 5,
            print -deps imp5.eps
         elseif j == 6,
            print -deps imp6.eps
         else
         end;
      else
         pause;
      end;
   end;
   for j = 1 : min(nvar,NVAR_MAX),
      if j == 1,
         fv = fv1;
         fv_m = mean(fv1');
         fv_s = std(fv1');
      elseif j == 2,
         fv = fv2;
         fv_m = mean(fv2');
         fv_s = std(fv2');
      elseif j == 3,
         fv = fv3;
         fv_m = mean(fv3');
         fv_s = std(fv3');
      elseif j == 4,
         fv = fv4;
         fv_m = mean(fv4');
         fv_s = std(fv4');
      elseif j == 5,
         fv = fv5;
         fv_m = mean(fv5');
         fv_s = std(fv5');
      elseif j == 6,
         fv = fv6;
         fv_m = mean(fv6');
         fv_s = std(fv6');
      else
      end;
      fv_m = fv_m(1:PLOT_VAR);
      fv_s = fv_s(1:PLOT_VAR);
      if DO_FV_SORT,
         % disp('Fraction of variances: Calculating Error Bands');
         % disp(' directly from the drawn distribution');
         fv = fv(1:PLOT_VAR,:);
         fv_sort = sort(fv');
         fv_sort = fv_sort';
         number_of_draws = size(fv_sort);
         number_of_draws = number_of_draws(2);
         fv_mid  = interp1(1:number_of_draws,fv_sort',.5*(number_of_draws-1)+1);
         fv_up   = interp1(1:number_of_draws,fv_sort',uq*(number_of_draws-1)+1);
         fv_down = interp1(1:number_of_draws,fv_sort',lq*(number_of_draws-1)+1);
      else
         % disp('Fraction of variances: Calculating Error Bands');
         % disp(' via means and standard deviations');
         fv_mid   = fv_m;
         if DO_2STDDEV,
            fv_up    = fv_m + 2 * fv_s;
            fv_down  = fv_m - 2 * fv_s;
         else
            fv_up    = fv_m +  fv_s;
            fv_down  = fv_m -  fv_s;
         end;
      end;
      if DO_FV_FOR_MEAN,
         hndl = plot(hor_v,fv_mid,'-',hor_v,fv_up,'-',hor_v,fv_down,'-',...
              hor_v,vf_par(1:PLOT_VAR,j),'-.',hor_v,0*hor_v);
         if DO_FV_SORT,
            % text(hor_v(5),fv_mid(5),'median v.f.');
         else
            % text(hor_v(5),fv_mid(5),'mean v.f.');
         end;
         % text(hor_v(20),vf_par(20,j),'v.f. for mean');
      else
         hndl = plot(hor_v,fv_mid,'-',hor_v,fv_up,'-',hor_v,fv_down,'-',hor_v,0*hor_v);
      end;
      title(['Fraction of variance explained for ',names(j,:)]);
      xlabel('years'); % xlabel('month');
      ylabel('Percent'); % ylabel('response');
      
      hpar = get(hndl(1),'Parent');
      set(hpar,'FontSize',FONT_SIZE);
      ht = get(hpar,'Title');
      set(ht,'FontSize',FONT_SIZE);
      hx = get(hpar,'XLabel');
      set(hx,'FontSize',FONT_SIZE);
      hy = get(hpar,'YLabel');
      set(hy,'FontSize',FONT_SIZE);

      if DO_EPSFILES,
         if j == 1,
            print -deps fv1.eps
         elseif j == 2,
            print -deps fv2.eps
         elseif j == 3,
            print -deps fv3.eps
         elseif j == 4,
            print -deps fv4.eps
         elseif j == 5,
            print -deps fv5.eps
         elseif j == 6,
            print -deps fv6.eps
         else
         end;
      else
         pause;
      end;
   end; 
end;

if DO_COUNTER,
   for j = 1 : min(nvar,NVAR_MAX),
      if j == 1,
         sernew = sernew1;
      elseif j == 2,
         sernew = sernew2;
      elseif j == 3,
         sernew = sernew3;
      elseif j == 4,
         sernew = sernew4;
      elseif j == 5,
         sernew = sernew5;
      elseif j == 6,
         sernew = sernew6;
      else
      end;
      if j~=6,
         sernew = 100*sernew/sernew(LEADDATES,1);
         serpar = 100*sernew_par(:,j)/sernew_par(LEADDATES,j);
         serold = 100*series(PIECE,j)/series(PIECE(LEADDATES),j);
      else % Federal Funds Rate
         sernew = scale_old(j)*sernew;
         serpar = scale_old(j)*sernew_par(:,j);
         serold = scale_old(j)*series(PIECE,j);
      end;
      sernew_m = mean(sernew');
      sernew_s = std(sernew');
      if DO_SERNEW_SORT,
         % disp('Counterfactual: Calculating Error Bands');
         % disp(' directly from the drawn distribution');
         sernew_sort = sort(sernew');
         sernew_sort = sernew_sort';
         number_of_draws = size(sernew_sort);
         number_of_draws = number_of_draws(2);
         sernew_mid  = interp1(1:number_of_draws,sernew_sort',.5*(number_of_draws-1)+1);
         sernew_up   = interp1(1:number_of_draws,sernew_sort',uq*(number_of_draws-1)+1);
         sernew_down = interp1(1:number_of_draws,sernew_sort',lq*(number_of_draws-1)+1);
      else
         % disp('Counterfactual: Calculating Error Bands');
         % disp(' via means and standard deviations');
         sernew_mid   = sernew_m;
         if DO_2STDDEV,
            sernew_up    = sernew_m + 2 * sernew_s;
            sernew_down  = sernew_m - 2 * sernew_s;
         else
            sernew_up    = sernew_m +  sernew_s;
            sernew_down  = sernew_m -  sernew_s;
         end;
      end;
      if DO_SERNEW_FOR_MEAN,
         hndl = plot(time(PIECE),serold,'-', time(PIECE),sernew_mid,'-.',time(PIECE),sernew_up,'-.',...
                     time(PIECE),sernew_down,'-.',time(PIECE),serpar,'--');
         if DO_SERNEW_SORT,
            % text(time(PIECE(5)),sernew_mid(5),'median i.r.');
         else
            % text(time(PIECE(5)),sernew_mid(5),'mean i.r.');
         end;
         % text(time(PIECE(20)),sernew_par(20,j),'i.r. for mean');
      else
         % hndl = plot(time(PIECE),serold,'-',time(PIECE),sernew_mid,'-.',time(PIECE),sernew_up,'-.',...
         %      time(PIECE),sernew_down,'-.');
         hndl = plot(time(PIECE),serold,'-',time(PIECE),sernew_up,'--',...
              time(PIECE),sernew_down,'--');
      end;
      set(hndl(1),'LineWidth',2);
      % text(time(PIECE(20)),serold(20),'Actual');
      % text(time(PIECE(30)),sernew_up(30),'Counterfactual (upper band)');
      % text(time(PIECE(30)),sernew_down(30),'Counterfactual (lower band)');
      title(['Counterfactual analysis for ',names(j,:)]);
      xlabel('Date'); % xlabel('month');
      if j~=6,
         ylabel('Value (July. 1979 = 100)'); % ylabel('response');
      else
         ylabel('Percent'); % ylabel('response');
      end;
      
      hpar = get(hndl(1),'Parent');
      set(hpar,'FontSize',FONT_SIZE);
      ht = get(hpar,'Title');
      set(ht,'FontSize',FONT_SIZE);
      hx = get(hpar,'XLabel');
      set(hx,'FontSize',FONT_SIZE);
      hy = get(hpar,'YLabel');
      set(hy,'FontSize',FONT_SIZE);

      if DO_EPSFILES,
         if j == 1,
            print -deps counter1.eps
         elseif j == 2,
            print -deps counter2.eps
         elseif j == 3,
            print -deps counter3.eps
         elseif j == 4,
            print -deps counter4.eps
         elseif j == 5,
            print -deps counter5.eps
         elseif j == 6,
            print -deps counter6.eps
         else
         end;
      else
         pause;
      end;
   end;
end;

